package com.tuigai.tuigai_tongcheng_api.config;

import org.springframework.amqp.core.*;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.HashMap;

@Configuration
public class RabbitMqConfig {

    /***************飞猪商旅回调mq*********************/
    public static final String TRAINSL_ORDER_EXCHANGE_NAME = "new.trainsl.order.exchange";
    //来单邮件回调更新报价队列
    public static final String TRAINSL_ORDER_QUEUE_NAME = "new.trainsl.order.queue";
    //来单邮件回调更新报价路由key
    public static final String TRAINSL_ORDER_QUEUE_ROUTING_KEY = "new.trainsl.order.queue.routingkey";

    // 声明 来单邮件回调更新报价 Exchange
    @Bean("trainslOrderExchange")
    public DirectExchange trainslOrderExchange() {
        return new DirectExchange(TRAINSL_ORDER_EXCHANGE_NAME);
    }

    //申明 来单邮件回调更新报价队列
    @Bean("trainslOrderQueue")
    public Queue trainslOrderQueueName() {
        return new Queue(TRAINSL_ORDER_QUEUE_NAME);
    }

    @Bean
    public Binding trainslorderExchangeBingding(@Qualifier("trainslOrderQueue") Queue queue,
                                                @Qualifier("trainslOrderExchange") DirectExchange exchange) {
        return BindingBuilder.bind(queue).to(exchange).with(TRAINSL_ORDER_QUEUE_ROUTING_KEY);
    }


    /*---------新订单-----开始------*/
    //来单回调更新报价 交换机
    public static final String NEWORDER_EXCHANGE_NAME = "newtrainorder.trainoa.exchange";
    //来单回调更新报价队列
    public static final String NEWORDER_QUEUE_NAME = "newtrainorder.trainoa.queue";
    //来单回调更新报价路由key
    public static final String NEWORDER_QUEUE_ROUTING_KEY = "newtrainorder.trainoa.queue.routingkey";

    // 声明 来单回调更新报价 Exchange
    @Bean("newtrainorderExchange")
    public DirectExchange neworderExchange() {
        return new DirectExchange(NEWORDER_EXCHANGE_NAME);
    }

    //申明 来单回调更新报价队列
    @Bean("newtrainorderQueue")
    public Queue neworderQueue() {
        return new Queue(NEWORDER_QUEUE_NAME);
    }

    @Bean
    public Binding neworderBingding(@Qualifier("newtrainorderQueue") Queue queue,
                                    @Qualifier("newtrainorderExchange") DirectExchange exchange) {
        return BindingBuilder.bind(queue).to(exchange).with(NEWORDER_QUEUE_ROUTING_KEY);
    }


    /*---------新订单-----开始------*/
    //来改签单回调更新报价 交换机
    public static final String NEWCHANGEORDER_EXCHANGE_NAME = "newchangetrainorder.trainoa.exchange";
    //来改签单回调更新报价队列
    public static final String NEWCHANGEORDER_QUEUE_NAME = "newchangetrainorder.trainoa.queue";
    //来改签单回调更新报价路由key
    public static final String NEWCHANGEORDER_QUEUE_ROUTING_KEY = "newchangetrainorder.trainoa.queue.routingkey";

    // 声明 来单回调更新报价 Exchange
    @Bean("newchangetrainorderExchange")
    public DirectExchange newchangetrainorderExchange() {
        return new DirectExchange(NEWCHANGEORDER_EXCHANGE_NAME);
    }

    //申明 来单回调更新报价队列
    @Bean("newchangetrainorderQueue")
    public Queue newchangetrainorderQueue() {
        return new Queue(NEWCHANGEORDER_QUEUE_NAME);
    }

    @Bean
    public Binding newchangeorderBingding(@Qualifier("newchangetrainorderQueue") Queue queue,
                                          @Qualifier("newchangetrainorderExchange") DirectExchange exchange) {
        return BindingBuilder.bind(queue).to(exchange).with(NEWCHANGEORDER_QUEUE_ROUTING_KEY);
    }



    /*---------退票分配订单-----开始------*/
    //交换机
    public static final String REFOUND_ALLOCATE_TICKETS_EXCHANGE_NAME = "refound.allocate.tickets.exchange";
    //队列
    public static final String REFOUND_ALLOCATE_TICKETS_QUEUE_NAME = "refound.allocate.tickets.queue";
    //路由key
    public static final String REFOUND_ALLOCATE_TICKETS_QUEUE_ROUTING_KEY = "refound.allocate.tickets.queue.routingkey";

    @Bean("refoundAllocateTicketsExchange")
    public DirectExchange refoundAllocateTicketsExchange() {
        return new DirectExchange(REFOUND_ALLOCATE_TICKETS_EXCHANGE_NAME);
    }

    @Bean("refoundAllocateTicketsQueue")
    public Queue refoundAllocateTicketsQueue() {
        return new Queue(REFOUND_ALLOCATE_TICKETS_QUEUE_NAME);
    }

    @Bean
    public Binding refoundAllocateTicketsExchangeBingding(@Qualifier("refoundAllocateTicketsQueue") Queue queue,
                                                          @Qualifier("refoundAllocateTicketsExchange") DirectExchange exchange) {
        return BindingBuilder.bind(queue).to(exchange).with(REFOUND_ALLOCATE_TICKETS_QUEUE_ROUTING_KEY);
    }
    /*---------退票分配订单---结束--------*/





    /*---------异步及延迟打印处理消息-----开始------*/
    //淘宝流水处理消息 交换机
    public static final String ORDER_PRINT_DELAY_EXCHANGE_NAME = "orderPrint.trainoa.exchange";
    //淘宝流水处理消息队列
    public static final String ORDER_PRINT_DELAY_QUEUE_NAME = "orderPrint.trainoa.queue";
    //淘宝流水处理消息路由key
    public static final String ORDER_PRINT_DELAY_QUEUE_ROUTING_KEY = "orderPrint.trainoa.queue.routingkey";

    // 声明 淘宝流水处理消息 Exchange
    @Bean
    public CustomExchange orderPrintDelayedExchange() {
        HashMap<String, Object> args = new HashMap<>();
        args.put("x-delayed-type", "direct");
        return new CustomExchange(ORDER_PRINT_DELAY_EXCHANGE_NAME, "x-delayed-message", true, false, args);
    }

    @Bean
    public Queue orderPrintDelayedQueue() {
        return new Queue(ORDER_PRINT_DELAY_QUEUE_NAME, true);
    }

    @Bean
    public Binding alipayDelayedBinding(@Qualifier("orderPrintDelayedQueue") Queue queue, @Qualifier("orderPrintDelayedExchange") CustomExchange customExchange) {
        return BindingBuilder.bind(queue).to(customExchange).with(ORDER_PRINT_DELAY_QUEUE_ROUTING_KEY).noargs();
    }
    /*---------异步及延迟打印处理消息---结束--------*/



    /***************打印信息修改mq*********************/
    public static final String ORDER_PRINT_EXCHANGE_NAME = "order.print.exchange";
    //来单邮件回调更新报价队列
    public static final String ORDER_PRINT_QUEUE_NAME = "order.print.queue";
    //来单邮件回调更新报价路由key
    public static final String ORDER_PRINT_QUEUE_ROUTING_KEY = "order.print.queue.routingkey";

    // 声明 来单邮件回调更新报价 Exchange
    @Bean("orderPrintExchange")
    public DirectExchange orderPrintExchange() {
        return new DirectExchange(ORDER_PRINT_EXCHANGE_NAME);
    }

    //申明 来单邮件回调更新报价队列
    @Bean("orderPrintQueue")
    public Queue orderPrintQueueName() {
        return new Queue(ORDER_PRINT_QUEUE_NAME);
    }

    @Bean
    public Binding orderPrintExchangeBingding(@Qualifier("orderPrintQueue") Queue queue,
                                              @Qualifier("orderPrintExchange") DirectExchange exchange) {
        return BindingBuilder.bind(queue).to(exchange).with(ORDER_PRINT_QUEUE_ROUTING_KEY);
    }



    /***************同程回调mq*********************/
    public static final String TRAINTC_ORDER_EXCHANGE_NAME = "new.traintc.order.exchange";
    //来单邮件回调更新报价队列
    public static final String TRAINTC_ORDER_QUEUE_NAME = "new.traintc.order.queue";
    //来单邮件回调更新报价路由key
    public static final String TRAINTC_ORDER_QUEUE_ROUTING_KEY = "new.traintc.order.queue.routingkey";

    // 声明 来单邮件回调更新报价 Exchange
    @Bean("traintcOrderExchange")
    public DirectExchange traintcOrderExchange() {
        return new DirectExchange(TRAINTC_ORDER_EXCHANGE_NAME);
    }

    //申明 来单邮件回调更新报价队列
    @Bean("traintcOrderQueue")
    public Queue traintcOrderQueueName() {
        return new Queue(TRAINTC_ORDER_QUEUE_NAME);
    }

    @Bean
    public Binding traintcorderExchangeBingding(@Qualifier("traintcOrderQueue") Queue queue,
                                                @Qualifier("traintcOrderExchange") DirectExchange exchange) {
        return BindingBuilder.bind(queue).to(exchange).with(TRAINTC_ORDER_QUEUE_ROUTING_KEY);
    }

}

