package com.tuigai.tuigai_tongcheng_api.consumer;

import com.alibaba.fastjson.JSONObject;
import com.rabbitmq.client.Channel;

import com.tuigai.tuigai_tongcheng_api.config.RabbitMqConfig;
import com.tuigai.tuigai_tongcheng_api.consumer.service.MsgConsumerService;
import com.tuigai.tuigai_tongcheng_api.model.OrderOptLog;
import com.tuigai.tuigai_tongcheng_api.service.OrderOptLogServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.Date;

@Component
@Slf4j
public class MsgConsumer {

    @Autowired
    private OrderOptLogServiceImpl orderOptLogService;

    @Autowired
    private MsgConsumerService msgConsumerService;

    @RabbitListener(queues = RabbitMqConfig.TRAINTC_ORDER_QUEUE_NAME)
    public void dealTrainSLOrder(Message message, Channel channel) throws IOException {
        //解析得到对象
        String mes = new String(message.getBody(), "utf-8");
        log.info("接收差旅订单推送处理：{}", mes);
        JSONObject jsonObject = JSONObject.parseObject(mes);
        try {
            msgConsumerService.callbackOrder(jsonObject);
        } catch (Exception e) {
            log.info("回调差旅出现了异常 {}", jsonObject, e);
            OrderOptLog optLog = new OrderOptLog().init(new Date(), jsonObject.getString("outId"));
            optLog.optDesc = "回填异常";
            orderOptLogService.addOrderOptLog(optLog);
        } finally {
            //最终手动确认消费
            channel.basicAck(message.getMessageProperties().getDeliveryTag(), false);
        }
    }
}
