package com.tuigai.tuigai_tongcheng_api.msg;

import com.tuigai.tuigai_tongcheng_api.config.RabbitMqConfig;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.AmqpException;
import org.springframework.amqp.core.*;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.nio.charset.StandardCharsets;
import java.util.Date;

@Component
@Slf4j
public class MessageSender {
    @Autowired
    private RabbitTemplate rabbitTemplate;


    /**
     * 通知新订单
     *
     * @param msg
     */
    public void newtrainorderSendMsg(String msg) {
        //配置消息的属性contentType
        MessageProperties properties = MessagePropertiesBuilder.newInstance()
                .setContentType(MessageProperties.CONTENT_TYPE_JSON)
                .build();
        //构建消息对象
        Message message = null;
        message = MessageBuilder.withBody(msg.getBytes(StandardCharsets.UTF_8))
                .andProperties(properties)
                .build();
        //发送
        //System.out.println("我发送了新车票订单："+msg);
        rabbitTemplate.convertAndSend(RabbitMqConfig.NEWORDER_EXCHANGE_NAME, RabbitMqConfig.NEWORDER_QUEUE_ROUTING_KEY, message);
    }


    public void newchangeorderSendMsg(String msg) {
        MessageProperties properties = MessagePropertiesBuilder.newInstance()
                .setContentType(MessageProperties.CONTENT_TYPE_JSON)
                .build();
        //构建消息对象
        Message message = null;
        message = MessageBuilder.withBody(msg.getBytes(StandardCharsets.UTF_8))
                .andProperties(properties)
                .build();
        //发送
        System.out.println("我发送了新改签订单分单消息：" + msg);
        rabbitTemplate.convertAndSend(RabbitMqConfig.NEWCHANGEORDER_EXCHANGE_NAME, RabbitMqConfig.NEWCHANGEORDER_QUEUE_ROUTING_KEY, message);

    }

    // 退票分单
    public void newAllocateMag(String msg) {
        MessageProperties properties = MessagePropertiesBuilder.newInstance()
                .setContentType(MessageProperties.CONTENT_TYPE_JSON)
                .build();
        //构建消息对象
        Message message = null;
        message = MessageBuilder.withBody(msg.getBytes(StandardCharsets.UTF_8))
                .andProperties(properties)
                .build();
        //发送
        log.info("对MQ发送退票重新分配票点信息：{}", msg);
        rabbitTemplate.convertAndSend(RabbitMqConfig.REFOUND_ALLOCATE_TICKETS_EXCHANGE_NAME, RabbitMqConfig.REFOUND_ALLOCATE_TICKETS_QUEUE_ROUTING_KEY, message);

    }

    public void newOrderPrintMagDelay(String msg, Integer delayTime) {
        //配置消息的属性contentType
        MessageProperties properties = MessagePropertiesBuilder.newInstance()
                .setContentType(MessageProperties.CONTENT_TYPE_JSON)
                .build();
        //构建消息对象
        Message message = null;
        message = MessageBuilder.withBody(msg.getBytes(StandardCharsets.UTF_8))
                .andProperties(properties)
                .build();
        // 延迟发送
        MessagePostProcessor processor = new MessagePostProcessor() {
            @Override
            public Message postProcessMessage(Message message) throws AmqpException {
                // 设置消息延时处理的时间
                message.getMessageProperties().setDelay(delayTime);
                message.getMessageProperties().setContentType(MessageProperties.CONTENT_TYPE_TEXT_PLAIN);
                return message;
            }
        };

        //发送

        rabbitTemplate.convertAndSend(RabbitMqConfig.ORDER_PRINT_DELAY_EXCHANGE_NAME, RabbitMqConfig.ORDER_PRINT_DELAY_QUEUE_ROUTING_KEY, message, processor);
        log.info("我发送了淘宝流水延时处理新消息：{},延迟时间：{}", msg, delayTime);
        log.info("发送时间：{}", new Date());
    }

    public void newOrderPrintMag(String msg) {
        MessageProperties properties = MessagePropertiesBuilder.newInstance()
                .setContentType(MessageProperties.CONTENT_TYPE_JSON)
                .build();
        //构建消息对象
        Message message = null;
        message = MessageBuilder.withBody(msg.getBytes(StandardCharsets.UTF_8))
                .andProperties(properties)
                .build();
        //发送
        log.info("对MQ发送商旅信息：{}", msg);
        rabbitTemplate.convertAndSend(RabbitMqConfig.ORDER_PRINT_EXCHANGE_NAME, RabbitMqConfig.ORDER_PRINT_QUEUE_ROUTING_KEY, message);
    }
}
