package com.tuigai.tuigai_tongcheng_api.service;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.tuigai.tuigai_tongcheng_api.model.RefoundTrainOrder;
import com.tuigai.tuigai_tongcheng_api.msg.MessageSender;
import com.tuigai.tuigai_tongcheng_api.redis.StringRedisService;
import com.tuigai.tuigai_tongcheng_api.utils.RefundOrderUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.IOException;

@Service
@Slf4j
public class OrderService {

    @Autowired
    private StringRedisService redisService;

    @Autowired
    private RefoundTrainOrderServiceImpl refoundTrainOrderService;

    @Autowired
    private RefoundSegmentServiceImpl refoundSegmentService;

    @Autowired
    private RefoundPassengerServiceImpl refoundPassengerService;

    @Autowired
    private MessageSender messageSender;


    public void saveRefundOrder(String decodeStr) {
        JSONArray jsonArray = JSONArray.parseArray(decodeStr);
        for (Object json : jsonArray) {
            try {
                JSONObject jsonObject = (JSONObject) json;
                JSONObject refundOrderJson = jsonObject.getJSONObject("refundOrder");
                String outId = refundOrderJson.getString("refundSerialNo");
                String key = StringRedisService.REFUND_HANDLE_ORDER + outId;
                if (redisService.isExistKey(key)) {
                    continue;
                }
                RefoundTrainOrder refoundTrainOrder = RefundOrderUtils.generateRefundOrder(jsonObject);
                //保存退票行程信息
                refoundSegmentService.addRefoundSegment(refoundTrainOrder.getRefoundSegmentList());
                //保存退票乘客信息
                refoundPassengerService.addRefoundPasengerBatch(refoundTrainOrder.getRefoundPasengerList());
                //保存退票订单信息
                refoundTrainOrderService.addRefoundTrainOrder(refoundTrainOrder);
                redisService.setStringAndLive(key, "1", 24 * 60 * 60);

                //发送派单消息
                JSONObject msgJson = new JSONObject();
                msgJson.put("outId", outId);
                messageSender.newAllocateMag(msgJson.toJSONString());
            } catch (Exception e) {
                log.error("异常", e);
            }
        }
    }


}
