package com.tuigai.tuigai_tongcheng_api.service;



import com.tuigai.tuigai_tongcheng_api.mapper.RefoundTrainOrderMapper;
import com.tuigai.tuigai_tongcheng_api.model.RefoundTrainOrder;
import com.tuigai.tuigai_tongcheng_api.utils.DateUtil;
import com.tuigai.tuigai_tongcheng_api.utils.OrderStatus;
import com.tuigai.tuigai_tongcheng_api.utils.PageHelper;
import com.tuigai.tuigai_tongcheng_api.utils.Utils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.time.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @ClassName RefoundTrainOrderServiceImpl
 * @Description 退票
 * @Author Tx
 * @Date 2023/5/24 15:49
 * @Version 1.0
 */
@Service
@Slf4j
public class RefoundTrainOrderServiceImpl {

    @Autowired
    private RefoundTrainOrderMapper refoundTrainOrderMapper;


    public List<RefoundTrainOrder> searchRefoundTrainOrder(String outId, String orderId, String passengerName, String minTrainDate, String maxTrainDate, String fromStationName, String toStationName, String minCreateTime, String maxCreateTime, String trainCode, String returnState, String companyId, String certificateNo, String paySequenceNo, String orderSource, String returnOrderType, int page, int size) {
        List<RefoundTrainOrder> list = refoundTrainOrderMapper.searchRefoundTrainOrder(outId,orderId,passengerName,minTrainDate,maxTrainDate,fromStationName,
                toStationName,minCreateTime,maxCreateTime,trainCode,returnState,companyId, certificateNo,paySequenceNo,orderSource,returnOrderType, PageHelper.getPageStart(page,size),size);

        return list;
    }


    public RefoundTrainOrder getRefoundTrainOrderByOutId(String outId) {
        //        List<RefoundPasenger> refoundPasengerList = refoundPassengerService.getRefoundPasengerListByOrderId(outId);
//        List<TrainReturnPayNo> trainReturnPayNoList = trainReturnPayNoService.getTrainReturnPayNoByOrderId(refoundTrainOrder.orderId);
//        List<RefoundOrderOptLog> refoundOrderOptLogList = refoundOrderOptLogService.getRefoundOrderOptLog(outId);
////        List<RefoundSegment> refoundSegmentList = refoundSegmentService.getRefoundSegmentByOutId(outId);
//        refoundTrainOrder.refoundPasengerList = refoundPasengerList;
//        refoundTrainOrder.returnPayNoList = trainReturnPayNoList;
//        refoundTrainOrder.refoundOrderOptLogList = refoundOrderOptLogList;
        return refoundTrainOrderMapper.getRefoundTrainOrderByorderId(outId);
    }


    public int updateRefoundTrainOrderStatusAndPayNoStatus(RefoundTrainOrder refoundTrainOrder) {
        return refoundTrainOrderMapper.updateRefoundTrainOrderStatusAndPayNoStatus(refoundTrainOrder);
    }


    public int updateRefoundTrainMainOrder(RefoundTrainOrder refoundTrainOrder) {
        return  refoundTrainOrderMapper.updateRefoundTrainOrder(refoundTrainOrder);
    }
    /**
     *  退票单大于2个，只要订单不是退票成功状态，都给加上 重复退票标记
     * @param orderId
     * @return`
     */

    public boolean changeRefoundOrderToChongfutui(String orderId) {
        List<RefoundTrainOrder> list = new ArrayList<>();
        if(Utils.isEmpty(orderId)) return false;
        String minDate = DateUtil.format(DateUtils.addMonths(new Date(),-2) , DateUtil.Format.YMD_HH_MM_SS);
        String maxDate = DateUtil.format(new Date(), DateUtil.Format.YMD_HH_MM_SS);
        list = searchRefoundTrainOrder("",orderId,"","","","","",minDate,maxDate,"","","","","","","",0,100);
        if(list.size() > 1){
            for(RefoundTrainOrder refoundTrainOrder : list){
                if(Utils.isEmpty(refoundTrainOrder.returnState) || refoundTrainOrder.returnState != OrderStatus.TUIPIAOCHENGGONG || refoundTrainOrder.returnState != OrderStatus.TUIPIAOSHIBAI){//不是退票成功
                    if(!refoundTrainOrder.returnOrderType.equals(OrderStatus.RETURNORDER_TYPE_BENRENTUI)) {
                        refoundTrainOrder.returnOrderSpecial = OrderStatus.RETURNSPECIAL_CHONGFUTUIPIAO;
                        updateRefoundTrainOrderStatusAndPayNoStatus(refoundTrainOrder);
                    }
                }
            }
            return true;
        }

        return false;
    }

    @Transactional(rollbackFor = Exception.class)
    public int addRefoundTrainOrder(RefoundTrainOrder refoundTrainOrder) {
        int i = refoundTrainOrderMapper.addRefoundTrainOrder(refoundTrainOrder);
        //赋值outId
//        for(RefoundPasenger refoundPasenger : refoundTrainOrder.refoundPasengerList){
//            refoundPasenger.outId = refoundTrainOrder.outId;
//        }
//        refoundSegmentService.addRefoundSegment(refoundTrainOrder.refoundSegmentList);
//        refoundPassengerService.addRefoundPasenger(refoundTrainOrder.refoundPasengerList);
        return i;
    }
    /**
     * 查看是否存在相同的退票单，根据退票订单号和乘机人
     * @param refoundTrainOrder
     * @return
     */

    public boolean isExitSameRefoundTrainOrder(RefoundTrainOrder refoundTrainOrder) {
        List<RefoundTrainOrder> list =  searchRefoundTrainOrder("",refoundTrainOrder.orderId,"","","",
                "","","","","","","","",
                "","","",0,200);
        if(Utils.isEmpty(list)){
            return false;
        }else {
            //需要把之前的退票单也标记为重复退票
            for(RefoundTrainOrder refoundTrainOrderTemp : list){
                refoundTrainOrderTemp.returnOrderSpecial = "2";
                refoundTrainOrderMapper.updateRefoundTrainOrder(refoundTrainOrderTemp);


            }
            return true;
        }
    }
    /**
     * 过滤出有同样SamesubOrderId的订单个数
     * @param refoundTrainOrder
     * @return
     */
    public int fliterSamesubOrderId(RefoundTrainOrder refoundTrainOrder) {
        int count = 0;
        List<RefoundTrainOrder> list =  searchRefoundTrainOrder("",refoundTrainOrder.orderId,"","","",
                "","","","","","","","",
                "","","",0,200);
        if(Utils.isEmpty(list)) {
            count = 0;
        }

        for(RefoundTrainOrder refoundTrainOrderTemp : list){
            if(refoundTrainOrder.orderId.equals(refoundTrainOrderTemp.orderId) && refoundTrainOrder.refoundPasengerList.get(0).passengerId.equals(refoundTrainOrderTemp.passengerId)){
                if(refoundTrainOrder.trainCode.equals(refoundTrainOrderTemp.trainCode)){
                    count = count +1;
                }

            }
        }
        if(count > 0){
            return  count + 1;
        }else {
            return  count;
        }
    }


    public int updateRefoundTrainOrderIsHaveZichuTui(RefoundTrainOrder refoundTrainOrder) {
        return  refoundTrainOrderMapper.updateRefoundTrainOrderIsHaveZichuTui(refoundTrainOrder);
    }

    public RefoundTrainOrder getRefoundTrainOrderByOutIdOne(String outId) {
       return refoundTrainOrderMapper.getRefoundTrainOrderByorderId(outId);
    }


    public int updateRefoundTrainOrderCallBackStatus(String outId, int callBackStatus) {
        return refoundTrainOrderMapper.updateRefoundTrainOrderCallBackStatus(outId,callBackStatus);
    }


    public int updateRefoundTrainOrderCallBackFailedAndStatus(String outId, int i,int status) {
        return refoundTrainOrderMapper.updateRefoundTrainOrderCallBackFailedAndStatus(outId, i,status);
    }


    public RefoundTrainOrder getByOrderIdAndReturnType(String orderId, String returnType) {
        return refoundTrainOrderMapper.getByOrderIdAndReturnType(orderId,returnType);
    }


    public List<RefoundTrainOrder> findByOrderIdAndReturnType(String orderId, String returnType) {
        return refoundTrainOrderMapper.findByOrderIdAndReturnType(orderId,returnType);
    }
}
