package com.tuigai.tuigai_tongcheng_api.utils;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

/**
 * Created by longtc on 15-4-8.
 */
public class DateUtil {

    public static final long INTERVAL_FIFTEEN_MINUTES = 15 * 60 * 1000;

    public static final long INTERVAL_HALF_HOUR = 2*INTERVAL_FIFTEEN_MINUTES;

    public static final long INTERVAL_HOUR = 2*INTERVAL_HALF_HOUR;
    public static final long INTERVAL_4HOUR = 4*2*INTERVAL_HALF_HOUR;

    public static final long INTERVAL_HALF_DAY = 12*INTERVAL_HOUR;

    public static final long INTERVAL_DAY = 2*INTERVAL_HALF_DAY;

    public enum Format {
        YMD("yyyy-MM-dd"),
        YMD_HH_MM("yyyy-MM-dd HH:mm"),
        YMD_HH_MM_SS("yyyy-MM-dd HH:mm:ss"),
        HH_MM("HH:mm");

        private final String fStr;

        Format(String str) {
            fStr = str;
        }

        public String strOf() {
            return fStr;
        }
    }



    public static String format(long time, Format format) {
        SimpleDateFormat df = new SimpleDateFormat(format.strOf());
        return df.format(time);
    }

    /**
     * 转换携程的奇葩日期为long
     * @param dataString
     * @return
     */
    public static long formatCtripDate(String dataString) {
        if (dataString.indexOf("Date") < 0) return 0L;
        //奇葩日期格式/Date(421430400000+0800)/
        String dateStr = dataString.replace("/Date(", "");
        return Long.valueOf(dateStr.substring(0,dateStr.length()-7));
    }

    public static String format(Date date, Format format) {
        return format(date.getTime(), format);
    }

    public static String format(long time) {
        return format(time, Format.YMD_HH_MM_SS);
    }

    public static String format(Date date) {
        return format(date, Format.YMD_HH_MM_SS);
    }

    public static Date parse2Date(String time, Format format) {
        SimpleDateFormat df = new SimpleDateFormat(format.strOf());
        try {
            Date d =  df.parse(time);
            return d;
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return null;
    }

    public static long parse2Long(String time, Format format) {
        Date d = parse2Date(time, format);
        if (d != null) {
            return d.getTime();
        }

        return 0;
    }

    public static int getTimeDay(long time) {
        return (int) (time / INTERVAL_DAY);
    }

    public static int getToday() {
        return getTimeDay(System.currentTimeMillis());
    }


    /**
     * 获取两个日期之间的每一天日期
     * @param begintTime
     * @param endTime
     * @return
     */
    public static List<String> findeveryDays(String begintTime, String endTime) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        Date dBegin = null;
        Date dEnd = null;
        try {
            dBegin = sdf.parse(begintTime);
            dEnd = sdf.parse(endTime);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        List daysStrList = new ArrayList();
        daysStrList.add(sdf.format(dBegin));
        Calendar calBegin = Calendar.getInstance();
        calBegin.setTime(dBegin);
        Calendar calEnd = Calendar.getInstance();
        calEnd.setTime(dEnd);
        while (dEnd.after(calBegin.getTime())) {
            calBegin.add(Calendar.DAY_OF_MONTH, 1);
            String dayStr = sdf.format(calBegin.getTime());
            daysStrList.add(dayStr);
        }
        return daysStrList;
    }

    /**
     * 获取时间相差的分和秒
     * @param currentTime
     * @param firstTime
     * @return
     */
    public static String getTimeMMSS(Date currentTime,Date firstTime){
        long diff = currentTime.getTime() - firstTime.getTime();//这样得到的差值是微秒级别

        long minutes = (diff)/(1000* 60);  //获取分钟
        long s= (diff/1000-minutes*60);//获取秒
        String CountTime= minutes+"分"+s+"秒";
        return CountTime;
    }

    /**
     * 获取时间相差的秒
     * @param currentTime
     * @param firstTime
     * @return
     * 时间字符串的转换方法用
     * parse2Date("2004-01-02 11:30:59", Format.YMD_HH_MM_SS);
     */
    public static long getTimeSS(Date currentTime,Date firstTime){
        long diff = currentTime.getTime() - firstTime.getTime();//这样得到的差值是微秒级别
        return (diff/1000);//获取秒
    }

    public static int getTimeHH(Date currentTime,Date firstTime){
        long diff = currentTime.getTime() - firstTime.getTime();//这样得到的差值是微秒级别
        return (int)(diff/1000/60/60);//获取秒
    }
    //Date类型转Calendar类型
    private static Calendar dataToCalendar(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        return calendar;
    }

    public static int getTimeDiffDD(Date currentTime,Date firstTime){
        long diff = currentTime.getTime() - firstTime.getTime();//这样得到的差值是微秒级别
        long dd = (diff)/(1000* 60 * 60 * 24);  //获取天
        return (int)dd;
    }
    /**
     * 是否在ITAPI出票时间范围内
     * @param startTime 格式要求必须是 HH_MM
     * @param endTime 格式要求必须是 HH_MM
     * @return 在时间范围内，就返回true 否则返回false
     */
    public static boolean isInTime(String startTime,String endTime){
        if(Utils.isEmpty(startTime) || Utils.isEmpty(endTime)) return false;
        if(startTime.equals("00:00") && endTime.equals("23:59")) return true;
        try{
            int startTimeLong = getHHMMValue(startTime);
            int endTimeLong = getHHMMValue(endTime);
            String nowHHMM = DateUtil.format(new Date(), Format.HH_MM);
            int nowTimeLong = getHHMMValue(nowHHMM);
            if(startTimeLong > endTimeLong){//垮天了 比较用 or 关系
                if(nowTimeLong >= startTimeLong || nowTimeLong <= endTimeLong) return true;
            }else {//同一天 and 关系
                if(nowTimeLong >= startTimeLong && nowTimeLong <= endTimeLong)return true;
            }
        }catch (Exception e){
            return  false;
        }
        return false;
    }
    private static int getHHMMValue(String hhmm){
        if(!hhmm.contains(":")) return 0;
        String[] hhmmarry = hhmm.split(":");
        int value = Integer.valueOf(hhmmarry[0]) * 60 +  Integer.valueOf(hhmmarry[1]);
        return value;

    }
    public static void main(String[] args) {
        Date currentTime = parse2Date("2004-01-02 11:32:59", Format.YMD_HH_MM_SS);
        Date firstTime = parse2Date("2004-01-02 11:30:24", Format.YMD_HH_MM_SS);     //查询的数据时间
        System.out.println(getTimeMMSS(currentTime, firstTime));
        System.out.println(getTimeSS(currentTime, firstTime));
    }
}
