package com.tuigai.tuigai_tongcheng_api.utils;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.lang.UUID;
import cn.hutool.core.text.UnicodeUtil;
import com.alibaba.fastjson.JSONObject;
import com.tuigai.tuigai_tongcheng_api.enums.OrderSourceEnum;
import com.tuigai.tuigai_tongcheng_api.model.RefoundPasenger;
import com.tuigai.tuigai_tongcheng_api.model.RefoundSegment;
import com.tuigai.tuigai_tongcheng_api.model.RefoundTrainOrder;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@Slf4j
public class RefundOrderUtils {

    public static String url = "http://8.218.227.156:8010/post/refund/id";

    public static RefoundTrainOrder generateRefundOrder(JSONObject jsonObject) throws IOException {
        JSONObject refundPassengerJson = jsonObject.getJSONObject("refundPassenger");
        JSONObject refundOrderJson = jsonObject.getJSONObject("refundOrder");
        JSONObject refundSegmentJson = jsonObject.getJSONObject("refundSegment");
        String orderId = refundOrderJson.getString("orderSerialNo");
        Float ticketPrice = refundOrderJson.getFloat("ticketPrice");
        String ticketNo = refundOrderJson.getString("electronicTicketNo");
        String outId = refundOrderJson.getString("refundSerialNo");
        //请求身份证
        Map<String, Object> param = new HashMap<>();
        param.put("refundSerialNo", outId);
        param.put("partitionKey", refundOrderJson.getString("partitionKey"));
        param.put("ticketPrice", ticketPrice);
        String result = OkHttpUtil.doPostRequest(url, JSONObject.toJSONString(param));
        log.info("result", result);
        JSONObject resultJson = null;
        try {
            resultJson = Utils.isEmpty(result) || "null".equals(result) ? new JSONObject() : JSONObject.parseObject(result);
        } catch (Exception e) {
            log.error("订单id：{}", orderId, e);
            resultJson = new JSONObject();
        }
        String creditNo = resultJson.getString("creditNo");

        //乘客信息
        RefoundPasenger refoundPasenger = new RefoundPasenger();
        refoundPasenger.outId = outId;
        refoundPasenger.orderId = orderId;
        refoundPasenger.passengerName = UnicodeUtil.toString(refundPassengerJson.getString("fullName"));
        refoundPasenger.certificateNo = creditNo;
        refoundPasenger.certificateType = ConvertUtil.CertificateTypeConvertEnum.getSelfCodeByOtherCode(refundOrderJson.getString("creditType"));
        refoundPasenger.passengerId = UUID.randomUUID().toString();
        refoundPasenger.tel = refundOrderJson.getString("contactPhone");
        //refoundPasenger.sex = ConvertUtil.SexConvertEnum.getSelfCodeByOtherCode(SMS4.decrypt(passengerInfo.getSex()));
        //refoundPasenger.birthDate = SMS4.decrypt(passengerInfo.getBirthDate());
        //refoundPasenger.validDateEnd = SMS4.decrypt(passengerInfo.getValidDateEnd());

        //refoundPasenger.validDateStart = SMS4.decrypt(passengerInfo.getValidDateStart());
        refoundPasenger.price = ticketPrice;
        refoundPasenger.seatType = ConvertUtil.SeatTypeConvertEnum.getSelfCodeByName(resultJson.getString("seatClass"));
        //refoundPasenger.chexiangNo = refundTicketInfo.getCoachNo();
        //refoundPasenger.zuoweiNo = refundTicketInfo.getSeatNo();
        refoundPasenger.isReturn = 0;

        refoundPasenger.returnMoney = 0.0F;
        refoundPasenger.isCallBack = 0;
        //refoundPasenger.paySequenceNo = paySequenceNo;
        refoundPasenger.ticketType = ConvertUtil.TicketTypeConvertEnum.getSelfCodeByOtherCode(refundPassengerJson.getString("passengerType"));
        //refoundPasenger.trainId = refundTrainInfo.getTrainId();
        refoundPasenger.ticketNo = ticketNo;

        //行程信息
        RefoundSegment refoundSegment = new RefoundSegment();
        refoundSegment.outId = outId;
        refoundSegment.orderId = orderId;
        refoundSegment.from_station = UnicodeUtil.toString(refundSegmentJson.getString("departureStation"));
        refoundSegment.to_station = UnicodeUtil.toString(refundSegmentJson.getString("arrivalStation"));
        refoundSegment.from_time = DateUtil.formatDateTime(new Date(refundSegmentJson.getLong("gmtDeparture")));
        refoundSegment.to_time = DateUtil.formatDateTime(new Date(refundSegmentJson.getLong("gmtArrive")));
        refoundSegment.trainCode = refundSegmentJson.getString("trainCode");
        refoundSegment.seats = "";
        refoundSegment.segmentTotalPrice = ticketPrice;
        //refoundSegment.trainId = refundTrainInfo.getTrainId();
        //refoundSegment.trainDate = refundTrainInfo.getTrainDate();
        //refoundSegment.fromStationCode = refundTrainInfo.getFromStationCode();
        //refoundSegment.toStationCode = refundTrainInfo.getToStationCode();
        //refoundSegment.ticketNum = refundTrainInfo.getTicketNum();

        RefoundTrainOrder refoundTrainOrder = new RefoundTrainOrder();
        refoundTrainOrder.setBizOrderId(OrderNoUtil.dateFormatString(OrderSourceEnum.TCTG.getKey()));
        refoundTrainOrder.outId = outId;//设置ID 新的订单ID GQ44654653
        refoundTrainOrder.orderId = orderId;//原出票订单的ID TR开头的 TR46465
        refoundTrainOrder.orderId12306 = ticketNo;

        refoundTrainOrder.fromStationName = refoundSegment.from_station;
        refoundTrainOrder.toStationName = refoundSegment.to_station;
        refoundTrainOrder.trainCode = refoundSegment.trainCode;
        refoundTrainOrder.startTime = refoundSegment.to_time;
        //refoundTrainOrder.paper = 0;
        //refoundTrainOrder.onlinePay = 1;
        //refoundTrainOrder.companyId = String.valueOf(changeTrainOrder.getCompanyId());
        refoundTrainOrder.companyId = "0";// 暂时未分配票点，置为0
        refoundTrainOrder.setCreateTime(DateUtil.now());
        refoundTrainOrder.reqTime = DateUtil.now();
        refoundTrainOrder.returntype = "1";
        // 需要分配订单把订单状态变为 待分配
        refoundTrainOrder.returnState = OrderStatus.DAIFENPEI;
        refoundTrainOrder.returnMoney = 0f;
        refoundTrainOrder.code = "";//退票情况代码，参照【退票结果code说明】
        refoundTrainOrder.optUser = "system";
        refoundTrainOrder.orderSource = OrderSourceEnum.TCTG.getKey();
        refoundTrainOrder.orderPrice = ticketPrice;
        refoundTrainOrder.returnOrderType = "1";
        refoundTrainOrder.autopaySequenceNoStatus = "0";
        refoundTrainOrder.returnOrderSpecial = "0";
        refoundTrainOrder.remark = "";
        refoundTrainOrder.refundDeadline = "";
        //refoundTrainOrder.isHaveZichuTui = 2;
        //refoundTrainOrder.isReturnMoney = 1;
        refoundTrainOrder.refoundPasengerList = CollUtil.newArrayList(refoundPasenger);
        refoundTrainOrder.refoundSegmentList = CollUtil.newArrayList(refoundSegment);
        return refoundTrainOrder;
    }
}
